@@ -1,5 +1,6 @@
 """Define a client to interact with AirVisual."""
-from typing import Optional, Union
+from json.decoder import JSONDecodeError
+from typing import Optional
 
 import aiohttp
 
@@ -46,14 +47,29 @@ class Client:  # pylint: disable=too-few-public-methods
         async with self.websession.request(
             method, f"{base_url}/{endpoint}", headers=headers, params=params, json=json
         ) as resp:
-            data: Union[str, dict] = await resp.json(content_type=None)
+            try:
+                data = await resp.json(content_type=None)
+            except JSONDecodeError:
+                # The response can't be parsed as JSON, so we'll use its body text
+                # in an error:
+                response_text = await resp.text()
+                data = {"status": "fail", "data": {"message": response_text}}
+
+            if isinstance(data, str):
+                # In some cases, the AirVisual API will return a quoted string in its
+                # response body (e.g., "\"node not found\""), which is technically valid
+                # JSON. Additionally, AirVisual sets that response's Content-Type header
+                # to application/json (#smh). Together, these facotrs will allow a
+                # non-true-JSON  payload to escape the try/except above. So, if we get
+                # here, we use the string value (with quotes removed) to raise an error:
+                response_text = data.replace('"', "")
+                data = {"status": "fail", "data": {"message": response_text}}
+
             _raise_on_error(data)
-            return data  # type: ignore
+            return data
 
 
-def _raise_on_error(data: Union[str, dict]) -> None:
+def _raise_on_error(data: dict) -> None:
     """Raise the appropriate exception on error."""
-    if isinstance(data, str):
-        raise_error(data)
-    elif "status" in data and data["status"] != "success":
+    if "status" in data and data["status"] != "success":
         raise_error(data["data"]["message"])
